@@ -4,6 +4,7 @@ Broadworks OCI-P Interface Base Classes
 Base classes used by the types, requests and responses as well as
 other components like ElementInfo that are used by those.
 """
+import logging
 import re
 from collections import namedtuple
 from typing import Any
@@ -21,6 +22,9 @@ from broadworks_ocip.exceptions import OCIErrorResponse
 from broadworks_ocip.exceptions import OCIErrorUnexpectedAttribute
 
 
+logger = logging.getLogger(__name__)
+
+
 @attr.s(slots=True, frozen=True)
 class ElementInfo:
     """
@@ -45,6 +49,7 @@ class ElementInfo:
     is_required: bool = attr.ib(default=False)
     is_array: bool = attr.ib(default=False)
     is_table: bool = attr.ib(default=False)
+    is_abstract: bool = attr.ib(default=False)
 
 
 class OCIType:
@@ -81,10 +86,10 @@ class OCIType:
                         raise TypeError(
                             f"{cname}: Expected {elem.name} to be a table/list but it is {type(value)}",
                         )
-                # elif not isinstance(value, elem.type):
-                #     raise TypeError(
-                #         f"{cname}: Expected {elem.name} to be type {elem.type} but it is {type(value)}",
-                #     )
+                elif not isinstance(value, elem.type):
+                    raise TypeError(
+                        f"{cname}: Expected {elem.name} to be type {elem.type} but it is {type(value)}",
+                    )
                 setattr(self, elem.name, value)
                 del kwargs[elem.name]
             elif elem.is_required:
@@ -135,6 +140,11 @@ class OCIType:
         """Return the typename of the class"""
         return self.__class__.__name__
 
+    @classmethod
+    def class_to_property_(self, name):
+        """Map a XML class name to the associated property"""
+        return name[0].lower() + name[1:]
+
     def post_xml_decode_(self):
         """
         Carry out any operations after the XML decode
@@ -222,11 +232,19 @@ class OCIType:
                         col_item = etree.SubElement(row_item, "col")
                         col_item.text = col
         elif sub_element.is_complex:
-            elem = etree.SubElement(
-                element,
-                sub_element.xmlname,
-                nsmap=self._default_nsmap(),
-            )
+            if sub_element.is_abstract:
+                elem = etree.SubElement(
+                    element,
+                    sub_element.xmlname,
+                    {"{http://www.w3.org/2001/XMLSchema-instance}type": value.type_},
+                    nsmap=self._default_nsmap(),
+                )
+            else:
+                elem = etree.SubElement(
+                    element,
+                    sub_element.xmlname,
+                    nsmap=self._default_nsmap(),
+                )
             value.etree_sub_components_(elem)
         else:
             elem = etree.SubElement(
@@ -309,7 +327,12 @@ class OCIType:
         pass
 
     @classmethod
-    def build_from_node_(cls, elem: ElementInfo, node: etree._Element) -> Any:
+    def build_from_node_(
+        cls,
+        api: "BroadworksAPI",  # type: ignore # noqa
+        elem: ElementInfo,
+        node: etree._Element,
+    ) -> Any:
         """
         Creates an OCI subelement from a single  XML etree node
 
@@ -324,7 +347,19 @@ class OCIType:
             if elem.is_table:
                 return cls.decode_table_(node)
             elif elem.is_complex:
-                return elem.type.build_from_etree_(node)
+                if elem.is_abstract:
+                    if "{http://www.w3.org/2001/XMLSchema-instance}type" in node.attrib:
+                        thisclass = api.get_type_class(
+                            node.attrib[
+                                "{http://www.w3.org/2001/XMLSchema-instance}type"
+                            ],
+                        )
+                        logger.error(f"thisclass={thisclass}")
+                        return thisclass.build_from_etree_(api=api, element=node)
+                    else:
+                        return ValueError("Cannot decode abstract object")
+                else:
+                    return elem.type.build_from_etree_(api=api, element=node)
             elif elem.type == bool:
                 return elem.type(
                     True if node.text == "true" else False,
@@ -335,7 +370,12 @@ class OCIType:
             return None
 
     @classmethod
-    def build_from_etree_(cls, element: etree._Element, extras: Dict[str, Any] = {}):
+    def build_from_etree_(
+        cls,
+        api: "BroadworksAPI",  # type: ignore # noqa
+        element: etree._Element,
+        extras: Dict[str, Any] = {},
+    ):
         """
         Create an OciType based instance from an XML etree element
 
@@ -351,13 +391,17 @@ class OCIType:
                 result = []
                 nodes = element.findall(elem.xmlname)
                 for node in nodes:
-                    result.append(cls.build_from_node_(elem=elem, node=node))
+                    result.append(cls.build_from_node_(api=api, elem=elem, node=node))
                 initialiser[elem.name] = result
             else:
                 node = element.find(elem.xmlname)
                 if node is not None:
-                    initialiser[elem.name] = cls.build_from_node_(elem=elem, node=node)
-                # else...
+                    initialiser[elem.name] = cls.build_from_node_(
+                        api=api,
+                        elem=elem,
+                        node=node,
+                    )
+                # else:
                 # I am inclined to thow an error here - at least after checking if
                 # the thing is require, but the class builder should do that so lets
                 # let it do its thing
